use bevy::window::PrimaryWindow;
use bevy_inspector_egui::bevy_inspector;

use crate::prelude::*;

#[derive(Component)]
pub struct HideFromInspector;

pub struct InspectorPlugin;
impl Plugin for InspectorPlugin {
    fn build(&self, app: &mut App) {
        app.add_plugins((
            bevy_egui::EguiPlugin,
            bevy_inspector_egui::DefaultInspectorConfigPlugin,
        ));
        app.add_systems(Update, inspector_ui);
    }
}

fn inspector_ui(world: &mut World) {
    let Ok(egui_context) = world
        .query_filtered::<&mut bevy_egui::EguiContext, With<PrimaryWindow>>()
        .get_single(world)
    else {
        return;
    };
    let mut egui_context = egui_context.clone();

    egui::Window::new("World").show(egui_context.get_mut(), |ui| {
        egui::ScrollArea::vertical().show(ui, |ui| {
            egui::CollapsingHeader::new("Entities")
                .default_open(true)
                .show(ui, |ui| {
                    bevy_inspector::ui_for_world_entities_filtered::<Without<HideFromInspector>>(
                        world, ui, false,
                    );
                });
            egui::CollapsingHeader::new("Resources").show(ui, |ui| {
                bevy_inspector_egui::bevy_inspector::ui_for_resources(world, ui);
            });
            egui::CollapsingHeader::new("Assets").show(ui, |ui| {
                bevy_inspector_egui::bevy_inspector::ui_for_all_assets(world, ui);
            });
        });
    });
}
